import { Story, Canvas, Meta, Description } from "@storybook/addon-docs/blocks";
import { withKnobs, text } from "@storybook/addon-knobs";
import { html } from "lit-html";
import CATEGORIES from "../categories";

<Meta title={CATEGORIES.STATIC + "Buttons"} />

# Buttons

there are two types of Buttons: Buttons for forms/JavaScript actions and Button-Links that look like Buttons, but are actually `<a>`-Tags

## Button

A button is used for JavaScript actions and for actions on forms.

<Canvas
    mdxSource={`
    <button class="ui-button">Button</button>
`}
>
    <Story name="Button" parameters={{ decorators: [withKnobs] }}>
        {html` <button class="ui-button">${text("Label", "Button")}</button> `}
    </Story>
</Canvas>

## Green Button

Any `ui-button` can be turned green by adding `ui-button--green`

<Canvas
    mdxSource={`
    <button class="ui-button ui-button--green">Button</button>
`}
>
    <Story name="Green Button" parameters={{ decorators: [withKnobs] }}>
        {html`
            <button class="ui-button ui-button--green">
                ${text("Label", "Button")}
            </button>
        `}
    </Story>
</Canvas>

## Icon-only Button

A button that contains only an Icon. A descriptive text should be added via title-attribute

<Canvas
    mdxSource={`
    <button class="ui-button ui-button--icon-only" title="next"><ui-icon name="arrow-right"/></button>
`}
>
    <Story name="Icon-only Button" parameters={{ decorators: [withKnobs] }}>
        {html`<button class="ui-button ui-button--icon-only" title="next">
            <ui-icon name="arrow-right" />
        </button>`}
    </Story>
</Canvas>

# Button-Link

This is actually an `<a>`-Tag, it just looks like a Button

<Canvas
    mdxSource={`
    <a href="#" class="ui-button">Button-Link</a>
`}
>
    <Story name="Button-Link">
        {html` <a href="#" class="ui-button">Button-Link</a> `}
    </Story>
</Canvas>

## Icon-only Button-Link

Icon-only Button as an `<a>`-Tag.

<Canvas
    mdxSource={`
    <a href="#" class="ui-button ui-button--icon-only"><ui-icon name="arrow-right"/></a>
`}
>
    <Story name="Icon-only Button-Link">
        {html`
            <a href="#" class="ui-button ui-button--icon-only"
                ><ui-icon name="arrow-right"
            /></a>
        `}
    </Story>
</Canvas>
